Output

Enum Output 

pub enum Output {
    SpriteAndMask {
        sprite: SpriteOutput,
        mask: SpriteOutput,
    },
    Sprite(SpriteOutput),
    LinearEncodedChuncky {
        data: Vec<u8>,
        palette: Palette,
        bytes_width: usize,
        height: usize,
    },
    CPCMemoryStandard([u8; 16384], Palette),
    CPCMemoryOverscan([u8; 16384], [u8; 16384], Palette),
    CPCSplittingMemory(Vec<Output>),
    TilesList {
        tile_height: u32,
        tile_width: u32,
        horizontal_movement: TileHorizontalCapture,
        vertical_movement: TileVerticalCapture,
        palette: Palette,
        list: Vec<Vec<u8>>,
    },
}
Embeds the conversion output There must be one implementation per OuputFormat

Variants



SpriteAndMask

Fields



Sprite(SpriteOutput)



LinearEncodedChuncky

Fields

data: Vec<u8>
palette: Palette
bytes_width: usize
height: usize


CPCMemoryStandard([u8; 16384], Palette)

Result using one bank



CPCMemoryOverscan([u8; 16384], [u8; 16384], Palette)

Result using two banks



CPCSplittingMemory(Vec<Output>)

Result using several chunks of memory



TilesList

Result containing several tiles

Fields

tile_height: u32
tile_width: u32
horizontal_movement: TileHorizontalCapture
vertical_movement: TileVerticalCapture
palette: Palette
list: Vec<Vec<u8>>

Implementations

Source

impl Output

pub fn overscan_screen1(&self) -> Option<&[u8; 16384]>

Returns the bank that contains the first half of the screen

pub fn sprite(self) -> Option<SpriteOutput>

pub fn overscan_screen2(&self) -> Option<&[u8; 16384]>

Returns the bank that contains the second half of the screen

pub fn tiles_list(&self) -> Option<&[Vec<u8>]>

Returns the list of tiles