pub enum OutputFormat {
MaskedSprite {
sprite_format: SpriteEncoding,
mask_ink: Ink,
replacement_ink: Ink,
},
Sprite(SpriteEncoding),
LinearEncodedChuncky,
CPCMemory {
output_dimension: CPCScreenDimension,
display_address: DisplayAddress,
},
CPCSplittingMemory(Vec<OutputFormat>),
TileEncoded {
tile_width: TileWidthCapture,
tile_height: TileHeightCapture,
horizontal_movement: TileHorizontalCapture,
vertical_movement: TileVerticalCapture,
grid_width: GridWidthCapture,
grid_height: GridHeightCapture,
},
}Expand description
Specify the output format to be used TODO - add additional output format (for example zigzag sprites that can be usefull or sprite display routines)
Variants
MaskedSprite
Sprite(SpriteEncoding)
LinearEncodedChuncky
Chuncky output where each pixel is encoded in one byte (and is supposed to be vertically duplicated)
CPCMemory
CPC memory encoded. The binary can be directly included in a snapshot
CPCSplittingMemory(Vec<OutputFormat>)
CPC memory encoded to be used with hardware splitting. The vector only contains the Variant CPCMemory
TileEncoded
For quite complexe coding more related to very fast display
Fields
tile_width: TileWidthCaptureThe width of a tile
tile_height: TileHeightCaptureThe height of a tile
horizontal_movement: TileHorizontalCaptureThe way tile are horizontally captured
vertical_movement: TileVerticalCaptureThe way tile are vertically captured
grid_width: GridWidthCaptureThe width of the grid (i.e., the number of tiles present in a row)
grid_height: GridHeightCaptureThe height of the gris (i.e., the number of tiles present in a column)
Implementations
Sourceimpl OutputFormat
impl OutputFormat
Sourcepub fn vertically_shift_display_address(&mut self, delta: i32)
pub fn vertically_shift_display_address(&mut self, delta: i32)
For formats manipulating a display address, modify it vertically in order to make scroll the image
Sourcepub fn create_linear_encoded_sprite() -> Self
pub fn create_linear_encoded_sprite() -> Self
Generate output format for a linear sprite
pub fn create_graycode_encoded_sprite() -> Self
pub fn create_zigzag_graycode_encoded_sprite() -> Self
Sourcepub fn create_overscan_cpc_memory() -> Self
pub fn create_overscan_cpc_memory() -> Self
Generate output format for an overscan screen
Sourcepub fn create_overscan_cpc_memory_one_bank_per_line() -> Self
pub fn create_overscan_cpc_memory_one_bank_per_line() -> Self
Generate output format for an overscan screen for which each imageline is in a single bank (this is not the case for the standard overscan)
pub fn create_standard_cpc_memory() -> Self