pub enum TransformationPosition {
First,
Last,
Index(usize),
}Expand description
Encode the position of a line or column to transform in the source image
Variants
First
This is the very first line or column of the image
Last
This is the very last line or column of the image
Index(usize)
This is a specific index
Implementations
Sourceimpl TransformationPosition
impl TransformationPosition
Sourcepub fn absolute_position(self, size: usize) -> Option<usize>
pub fn absolute_position(self, size: usize) -> Option<usize>
Get the absolute position regarding the image size