pub struct DisplayAddress(/* private fields */);Expand description
Manage the display address contained in R12-R13 TODO move that later in a CRTC emulator code
Implementations
Sourceimpl DisplayAddress
impl DisplayAddress
pub fn new(page: u16, is_overscan: bool, offset: u16) -> Self
pub fn new_standard_from_page(page: u16) -> Self
Sourcepub fn new_overscan_from_page(page: u16) -> Self
pub fn new_overscan_from_page(page: u16) -> Self
Generate an address that allow to display overscan picture from the given page
Sourcepub fn new_overscan_from_page_one_bank_per_line(
page: u16,
char_width: u16,
) -> Self
pub fn new_overscan_from_page_one_bank_per_line( page: u16, char_width: u16, ) -> Self
Generate an overscan address where each line is contained in a single bank
pub fn new_standard_from_address(_address: u16) -> Self
pub fn new_overscan_from_address(_address: u16) -> Self
pub fn set_offset(&mut self, offset: u16)
pub fn set_buffer(&mut self, buffer: u16)
pub fn set_overscan(&mut self, is_overscan: bool)
Sourcepub fn page(self) -> u16
pub fn page(self) -> u16
Return the page configuration 0 0 0x0000 0 1 0x4000 1 0 0x8000 1 1 0xc000
pub fn set_page(&mut self, page: u16)
pub fn r12(self) -> u8
pub fn r13(self) -> u8
Sourcepub fn page_start(self) -> u16
pub fn page_start(self) -> u16
Return the page value
Sourcepub fn is_overscan(self) -> bool
pub fn is_overscan(self) -> bool
Check of the configuration correspond to an overscan
Sourcepub fn move_to_previous_word(&mut self)
pub fn move_to_previous_word(&mut self)
Change the adress to point to the previous word
Sourcepub fn move_to_next_word(&mut self)
pub fn move_to_next_word(&mut self)
Assume the object represent the character of interest and move to next one