TransformationColumnPosition

Type Alias TransformationColumnPosition 

pub type TransformationColumnPosition = TransformationPosition;
Type that represent the position in a column of the image

Aliased Type

pub enum TransformationColumnPosition {
    First,
    Last,
    Index(usize),
}

Variants



First

This is the very first line or column of the image



Last

This is the very last line or column of the image



Index(usize)

This is a specific index