TransformationLinePosition

Type Alias TransformationLinePosition 

pub type TransformationLinePosition = TransformationPosition;
Type that represent the position in a line of the image

Aliased Type

pub enum TransformationLinePosition {
    First,
    Last,
    Index(usize),
}

Variants



First

This is the very first line or column of the image



Last

This is the very last line or column of the image



Index(usize)

This is a specific index