ColorMatrix

Struct ColorMatrix 

pub struct ColorMatrix { /* private fields */ }
A ColorMatrix represents an image through a list of Inks. It has no real meaning in CPC world but can be used for image transformaton There is no mode information

Implementations

Source

impl ColorMatrix

pub const INK_MASK_BACKGROUND: Ink = Ink::BRIGHTWHITE

pub const INK_MASK_FOREGROUND: Ink = Ink::BLACK

pub const INK_NOT_USED_IN_MASK: Ink = Ink::RED

pub fn from_screen( data: &[u8], bytes_width: usize, mode: Mode, palette: &Palette, ) -> Self

pub fn from_sprite( data: &[u8], pixels_width: u16, mode: Mode, palette: &Palette, ) -> Self

Source

impl ColorMatrix

pub fn new(width: usize, height: usize) -> Self

Create a new empty color matrix for the given dimensions

pub fn extract_mask_and_sprite( &self, mask_ink: impl Into<Ink>, replacement_ink: impl Into<Ink>, ) -> (Self, Self)

The matrix represents both the mask (with an unexpected color), and the sprite (<ith the expected color). This method returns two matrices:

  • The mask where bright white stands for pixels of the sprite and black stands for the pixels of the background
  • The sprite where the background is replaced by a selected ink (Ideally the one that will be considered as being pen 0)
pub fn convert_to_mask(&mut self, mask: Ink) -> &mut Self

Destroy the image to build the mask according to the background ink

pub fn replace_ink(&mut self, from: Ink, to: Ink) -> &mut Self

Exchange all the occurrences of from Ink with to ink

pub fn empty() -> Self

pub fn empty_like(&self) -> Self

Create a new ColorMatrix that encodes a new image full of black

pub fn double_horizontally(&mut self)

Double the width (usefull for chuncky conversions)

pub fn remove_odd_columns(&mut self)

pub fn height(&self) -> u32

Get the height (in pixels) of the image TODO Use a trait for that

pub fn get_ink(&self, x: usize, y: usize) -> &Ink

Returns the ink at the right position

pub fn set_ink(&mut self, x: usize, y: usize, ink: Ink)

Set ink

pub fn add_line(&mut self, position: usize, line: &[Ink])

Add a line within the image Panic if impossible

pub fn get_line(&self, y: usize) -> &[Ink]

Returns a reference on the wanted line of inks

pub fn add_column(&mut self, position: usize, column: &[Ink])

Add a column within the image Panic if impossible

pub fn get_column(&self, x: usize) -> Vec<Ink>

Build a vector of Inks that contains all the inks of the given column

pub fn window( &self, start_x: usize, start_y: usize, width: usize, height: usize, ) -> Self

Return a copy of the inks for the given window definition

pub fn nb_inks(&self) -> usize

Return the number of different inks in the image

pub fn extract_palette(&self, mode: Mode) -> Palette

Returns the palette used (as soon as there is less than the maximum number of inks fr the requested mode)

pub fn reduce_colors_for_mode( &mut self, mode: Mode, strategy: ColorConversionStrategy, ) -> Result<(), Error>

Modify the image in order to keep the right amount of inks

pub fn reduce_colors_with( &mut self, inks: &[Ink], strategy: ColorConversionStrategy, ) -> Result<(), Error>

Modify the image in order to use only the provided palette

pub fn width(&self) -> u32

Get the width (in bytes) of the image TODO Use a trait for that

pub fn convert_from_fname( fname: &str, conversion: ConversionRule, ) -> Result<Self>

pub fn convert( img: &ImageBuffer<Rgb<u8>, Vec<u8>>, conversion: ConversionRule, ) -> Self

pub fn diff(&self, other: &Self) -> Self

Compute a difference map to see the problematic positions

pub fn diff_to_positions(&self) -> Vec<(usize, usize)>

From a ColorMatrix computed with the diff method, returns the (x,y) coordinates having a difference

pub fn as_image(&self) -> ImageBuffer<Rgba<u8>, Vec<u8>>

Convert the buffer as an image

pub fn as_sprite( &self, mode: Mode, palette: Option<Palette>, missing_pen: Option<Pen>, ) -> Sprite

Convert the matrix as a sprite, given the right mode and an optional palette

pub fn as_mode1_sprite_with_different_inks_per_line( &self, palette: &[(Ink, Ink, Ink, Ink)], dummy_palette: &Palette, missing_pen: Option<Pen>, ) -> Sprite

Convert the matrix as a sprite in mode1. Pen 1/2/3 are changed at each line. Pen 0 is constant

pub fn inks(&self) -> Inks<'_>

Generate an iterator on the pixels