pub struct MultiModeSprite { /* private fields */ }Expand description
Simple multimode sprite where each line can have its own resolution mode The palette is assumed to be the same on all the lines
Implementations
Sourceimpl MultiModeSprite
impl MultiModeSprite
pub fn bytes(&self) -> &Vec<Vec<u8>>
pub fn height(&self) -> usize
pub fn width(&self) -> usize
Sourcepub fn to_mode0_sprite(&self) -> Sprite
pub fn to_mode0_sprite(&self) -> Sprite
Build a standard mode 0 sprite from a multimode sprite Bytes values will be strictly the same. However representation is loss (bytes supposed to be displayed in mode 1, 2, 3 will be represented in mode 0) The multimode sprite is consummed
pub fn to_mode3_sprite(&self) -> Sprite
Sourcepub fn mode0_mode3_mix_from_mode0(
sprite: &Sprite,
conversion: MultiModeConversion,
) -> Self
pub fn mode0_mode3_mix_from_mode0( sprite: &Sprite, conversion: MultiModeConversion, ) -> Self
Generate a multimode sprite that mixes mode 0 and mode 3 and uses only 4 colors