pub type TransformationLinePosition = TransformationPosition;Expand description
Type that represent the position in a line of the image
Aliased Type
pub enum TransformationLinePosition {
First,
Last,
Index(usize),
}pub type TransformationLinePosition = TransformationPosition;Type that represent the position in a line of the image
pub enum TransformationLinePosition {
First,
Last,
Index(usize),
}